@@ -11,7 +11,7 @@
 #' @export
 #' @name MulticoreFuture-class
 #' @keywords internal
-MulticoreFuture <- function(expr=NULL, envir=parent.frame(), substitute=FALSE, globals=TRUE, ...) {
+MulticoreFuture <- function(expr = NULL, envir = parent.frame(), substitute = FALSE, globals = TRUE, ...) {
   if (substitute) expr <- substitute(expr)
 
   args <- list(...)
@@ -20,11 +20,11 @@ MulticoreFuture <- function(expr=NULL, envir=parent.frame(), substitute=FALSE, g
 
   ## Global objects
   assignToTarget <- (is.list(globals) || inherits(globals, "Globals"))
-  gp <- getGlobalsAndPackages(expr, envir=envir, tweak=tweakExpression, globals=globals, resolve=TRUE)
+  gp <- getGlobalsAndPackages(expr, envir = envir, tweak = tweakExpression, globals = globals)
 
   ## Assign?
    if (length(gp) > 0 && (lazy || assignToTarget)) {
-    target <- new.env(parent=envir)
+    target <- new.env(parent = envir)
     globalsT <- gp$globals
     for (name in names(globalsT)) {
       target[[name]] <- globalsT[[name]]
@@ -34,13 +34,15 @@ MulticoreFuture <- function(expr=NULL, envir=parent.frame(), substitute=FALSE, g
   }
   gp <- NULL
 
-  f <- MultiprocessFuture(expr=expr, envir=envir, substitute=FALSE, job=NULL, ...)
-  structure(f, class=c("MulticoreFuture", class(f)))
+  f <- MultiprocessFuture(expr = expr, envir = envir, substitute = FALSE, job = NULL, ...)
+  structure(f, class = c("MulticoreFuture", class(f)))
 }
 
 
 #' @export
 run.MulticoreFuture <- function(future, ...) {
+  debug <- getOption("future.debug", FALSE)
+  
   if (future$state != 'created') {
     stop("A future can only be launched once.")
   }
@@ -55,24 +57,26 @@ run.MulticoreFuture <- function(future, ...) {
   envir <- future$envir
 
   requestCore(
-    await=function() FutureRegistry("multicore", action="collect-first"),
-    workers=future$workers
+    await = function() FutureRegistry("multicore", action = "collect-first"),
+    workers = future$workers
   )
 
   ## Add to registry
-  FutureRegistry("multicore", action="add", future=future)
+  FutureRegistry("multicore", action = "add", future = future)
 
   future.args <- list(expr)
-  job <- do.call(parallel::mcparallel, args=future.args, envir=envir)
+  job <- do.call(parallel::mcparallel, args = future.args, envir = envir)
 
   future$job <- job
   future$state <- 'running'
 
+  if (debug) mdebug("%s started", class(future)[1])
+  
   invisible(future)
 }
 
 #' @export
-resolved.MulticoreFuture <- function(x, timeout=0.2, ...) {
+resolved.MulticoreFuture <- function(x, timeout = 0.2, ...) {
   ## Is future even launched?
   if (x$state == 'created') return(FALSE)
 
@@ -87,11 +91,11 @@ resolved.MulticoreFuture <- function(x, timeout=0.2, ...) {
   job <- x$job
   stopifnot(inherits(job, "parallelJob"))
 
-  ## NOTE: We cannot use mcollect(job, wait=FALSE, timeout=0.2),
+  ## NOTE: We cannot use mcollect(job, wait = FALSE, timeout = 0.2),
   ## because that will return NULL if there's a timeout, which is
   ## an ambigous value because the future expression may return NULL.
   ## WORKAROUND: Adopted from parallel::mccollect().
-  pid <- selectChildren(job, timeout=timeout)
+  pid <- selectChildren(job, timeout = timeout)
   res <- (is.integer(pid) || is.null(pid))
 
   ## Signal conditions early? (happens only iff requested)
@@ -101,7 +105,7 @@ resolved.MulticoreFuture <- function(x, timeout=0.2, ...) {
 }
 
 #' @export
-value.MulticoreFuture <- function(future, signal=TRUE, ...) {
+value.MulticoreFuture <- function(future, signal = TRUE, ...) {
   ## Has the value already been collected?
   if (future$state %in% c('finished', 'failed', 'interrupted')) {
     return(NextMethod("value"))
@@ -120,14 +124,14 @@ value.MulticoreFuture <- function(future, signal=TRUE, ...) {
   mccollect <- importParallel("mccollect")
   job <- future$job
   stopifnot(inherits(job, "parallelJob"))
-  res <- mccollect(job, wait=TRUE)[[1L]]
+  res <- mccollect(job, wait = TRUE)[[1L]]
 
   ## SPECIAL: Check for fallback 'fatal error in wrapper code'
   ## try-error from parallel:::mcparallel().  If detected, then
   ## turn into an error with a more informative error message, cf.
   ## https://github.com/HenrikBengtsson/future/issues/35
-  if (identical(res, structure("fatal error in wrapper code", class="try-error"))) {
-    stop(FutureError(sprintf("Detected an error ('%s') by the 'parallel' package while trying to retrieve the value of a %s (%s). This could be because the forked R process that evalutes the future was terminated before it was completed.", res, class(future)[1], sQuote(hexpr(future$expr))), future=future))
+  if (identical(res, structure("fatal error in wrapper code", class = "try-error"))) {
+    stop(FutureError(sprintf("Detected an error ('%s') by the 'parallel' package while trying to retrieve the value of a %s (%s). This could be because the forked R process that evaluates the future was terminated before it was completed.", res, class(future)[1], sQuote(hexpr(future$expr))), future = future))
   }
 
   ## Update value and state
@@ -142,13 +146,13 @@ value.MulticoreFuture <- function(future, signal=TRUE, ...) {
   res <- NULL ## Not needed anymore
 
   ## Remove from registry
-  FutureRegistry("multicore", action="remove", future=future)
+  FutureRegistry("multicore", action = "remove", future = future)
 
   NextMethod("value")
 }
 
 
 #' @export
-getExpression.MulticoreFuture <- function(future, mc.cores=0L, ...) {
-  NextMethod("getExpression", mc.cores=mc.cores)
+getExpression.MulticoreFuture <- function(future, mc.cores = 1L, ...) {
+  NextMethod("getExpression", mc.cores = mc.cores)
 }
